@@ -5,7 +5,6 @@ use super::*;
 use basic_dsp_vector::*;
 use basic_dsp_vector::combined_ops::*;
 use num_complex::Complex64;
-use std::sync::Arc;
 
 pub type VecBuf = InteropVec<f64>;
 
@@ -324,20 +323,6 @@ pub extern "C" fn div_points_ops1_f64(ops: &mut PreparedOp1F64, arg: usize) {
     ops.add_enum_op(Operation::DivPoints(arg))
 }
 
-#[no_mangle]
-pub extern "C" fn map_real_ops1_f64(ops: &mut PreparedOp1F64,
-                                    arg: usize,
-                                    map: extern "C" fn(f64, usize) -> f64) {
-    ops.add_enum_op(Operation::MapReal(arg, Arc::new(move |v, i| map(v, i))))
-}
-
-#[no_mangle]
-pub extern "C" fn map_complex_ops1_f64(ops: &mut PreparedOp1F64,
-                                       arg: usize,
-                                       map: extern "C" fn(Complex64, usize) -> Complex64) {
-    ops.add_enum_op(Operation::MapComplex(arg, Arc::new(move |v, i| map(v, i))))
-}
-
 #[no_mangle]
 pub extern "C" fn delete_ops1_f64(vector: Box<PreparedOp1F64>) {
     drop(vector);
@@ -562,20 +547,6 @@ pub extern "C" fn div_points_ops2_f64(ops: &mut PreparedOp2F64, arg: usize) {
     ops.add_enum_op(Operation::DivPoints(arg))
 }
 
-#[no_mangle]
-pub extern "C" fn map_real_ops2_f64(ops: &mut PreparedOp2F64,
-                                    arg: usize,
-                                    map: extern "C" fn(f64, usize) -> f64) {
-    ops.add_enum_op(Operation::MapReal(arg, Arc::new(move |v, i| map(v, i))))
-}
-
-#[no_mangle]
-pub extern "C" fn map_complex_ops2_f64(ops: &mut PreparedOp2F64,
-                                       arg: usize,
-                                       map: extern "C" fn(Complex64, usize) -> Complex64) {
-    ops.add_enum_op(Operation::MapComplex(arg, Arc::new(move |v, i| map(v, i))))
-}
-
 #[no_mangle]
 pub extern "C" fn delete_ops2_f64(vector: Box<PreparedOp2F64>) {
     drop(vector);
