@@ -8,9 +8,11 @@ pub mod combined_ops32;
 pub mod facade64;
 pub mod combined_ops64;
 use basic_dsp_vector::{VoidResult, SingleBuffer, TransRes, PaddingOption, GenDspVec, ScalarResult,
-                       ErrorReason, RealNumber};
+                       ErrorReason};
 use basic_dsp_vector::window_functions::*;
 use basic_dsp_vector::conv_types::*;
+use basic_dsp_vector::numbers::RealNumber;
+use num_complex::Complex;
 
 pub struct InteropVec<T>
     where T: RealNumber
@@ -134,7 +136,7 @@ pub fn translate_error(reason: ErrorReason) -> i32 {
 }
 
 pub fn translate_to_window_function<T>(value: i32) -> Box<WindowFunction<T>>
-    where T: RealNumber + 'static
+    where T: RealNumber
 {
     if value == 0 {
         Box::new(TriangularWindow)
@@ -146,7 +148,7 @@ pub fn translate_to_window_function<T>(value: i32) -> Box<WindowFunction<T>>
 pub fn translate_to_real_convolution_function<T>(value: i32,
                                                  rolloff: T)
                                                  -> Box<RealImpulseResponse<T>>
-    where T: RealNumber + 'static
+    where T: RealNumber
 {
     if value == 0 {
         Box::new(SincFunction::new())
@@ -158,7 +160,7 @@ pub fn translate_to_real_convolution_function<T>(value: i32,
 pub fn translate_to_real_frequency_response<T>(value: i32,
                                                rolloff: T)
                                                -> Box<RealFrequencyResponse<T>>
-    where T: RealNumber + 'static
+    where T: RealNumber
 {
     if value == 0 {
         Box::new(SincFunction::new())
@@ -215,3 +217,130 @@ pub struct ScalarInteropResult<T>
     /// The result
     pub result: T,
 }
+
+/// A window function which can be constructed outside this crate.
+struct ForeignWindowFunction<T>
+    where T: RealNumber
+{
+    /// The window function
+    pub window_function: extern "C" fn(*const std::os::raw::c_void, usize, usize) -> T,
+
+    /// The data which is passed to the window function
+    ///
+    /// Actual data type is a `const* c_void`, but Rust doesn't allow that because it's
+    /// unsafe so we store
+    /// it as `usize` and transmute it when necessary. Callers should make very sure safety
+    /// is guaranteed.
+    pub window_data: usize,
+
+    /// Indicates whether this function is symmetric around 0 or not.
+    /// Symmetry is defined as `self.window(x) == self.window(-x)`.
+    pub is_symmetric: bool,
+}
+
+impl<T> WindowFunction<T> for ForeignWindowFunction<T>
+    where T: RealNumber
+{
+    fn is_symmetric(&self) -> bool {
+        self.is_symmetric
+    }
+
+    fn window(&self, idx: usize, points: usize) -> T {
+        let fun = self.window_function;
+        fun(self.window_data as *const std::os::raw::c_void, idx, points)
+    }
+}
+
+/// A real function which can be constructed outside this crate.
+struct ForeignRealConvolutionFunction<T>
+    where T: RealNumber
+{
+    /// The function
+    pub conv_function: extern "C" fn(*const std::os::raw::c_void, T) -> T,
+
+    /// The data which is passed to the function.
+    ///
+    /// Actual data type is a `const* c_void`, but Rust doesn't allow that
+    /// because it's unsafe so we store
+    /// it as `usize` and transmute it when necessary. Callers should make
+    /// very sure safety is guaranteed.
+    pub conv_data: usize,
+
+    /// Indicates whether this function is symmetric around 0 or not.
+    /// Symmetry is defined as `self.calc(x) == self.calc(-x)`.
+    pub is_symmetric: bool,
+}
+
+impl<T> RealImpulseResponse<T> for ForeignRealConvolutionFunction<T>
+    where T: RealNumber
+{
+    fn is_symmetric(&self) -> bool {
+        self.is_symmetric
+    }
+
+    fn calc(&self, x: T) -> T {
+        let fun = self.conv_function;
+        fun(self.conv_data as *const std::os::raw::c_void, x)
+    }
+}
+
+impl<T> RealFrequencyResponse<T> for ForeignRealConvolutionFunction<T>
+    where T: RealNumber
+{
+    fn is_symmetric(&self) -> bool {
+        self.is_symmetric
+    }
+
+    fn calc(&self, x: T) -> T {
+        let fun = self.conv_function;
+        fun(self.conv_data as *const std::os::raw::c_void, x)
+    }
+}
+
+/// A complex function which can be constructed outside this crate.
+struct ForeignComplexConvolutionFunction<T>
+    where T: RealNumber
+{
+    /// The function
+    pub conv_function: extern "C" fn(*const std::os::raw::c_void, T) -> Complex<T>,
+
+    /// The data which is passed to the window function
+    ///
+    /// Actual data type is a `const* c_void`, but Rust doesn't allow that
+    /// because it's unsafe so we store
+    /// it as `usize` and transmute it when necessary. Callers should make very
+    /// sure safety is guaranteed.
+    pub conv_data: usize,
+
+    /// Indicates whether this function is symmetric around 0 or not.
+    /// Symmetry is defined as `self.calc(x) == self.calc(-x)`.
+    pub is_symmetric: bool,
+}
+
+impl<T> ComplexImpulseResponse<T> for ForeignComplexConvolutionFunction<T>
+    where T: RealNumber
+{
+    fn is_symmetric(&self) -> bool {
+        self.is_symmetric
+    }
+
+    fn calc(&self, x: T) -> Complex<T> {
+        let fun = self.conv_function;
+        fun(self.conv_data as *const std::os::raw::c_void, x)
+    }
+}
+
+impl<T> ComplexFrequencyResponse<T> for ForeignComplexConvolutionFunction<T>
+    where T: RealNumber
+{
+    fn is_symmetric(&self) -> bool {
+        self.is_symmetric
+    }
+
+    /// Indicates whether this function is symmetric around 0 or not.
+    /// Symmetry is defined as `self.calc(x) == self.calc(-x)`.
+    fn calc(&self, x: T) -> Complex<T> {
+        let fun = self.conv_function;
+        fun(self.conv_data as *const std::os::raw::c_void, x)
+    }
+}
